Struct amazon_sp_notifications::models::subscription::Subscription
source · [−]pub struct Subscription {
pub subscription_id: String,
pub payload_version: String,
pub destination_id: String,
pub processing_directive: Option<Box<ProcessingDirective>>,
}Expand description
Subscription : Represents a subscription to receive notifications.
Fields
subscription_id: StringThe subscription identifier generated when the subscription is created.
payload_version: StringThe version of the payload object to be used in the notification.
destination_id: StringThe identifier for the destination where notifications will be delivered.
processing_directive: Option<Box<ProcessingDirective>>Implementations
sourceimpl Subscription
impl Subscription